[evolution-data-server] Clean up the mess that is CalObjModType.
- From: Matthew Barnes <mbarnes src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [evolution-data-server] Clean up the mess that is CalObjModType.
- Date: Mon, 28 Jan 2013 21:42:27 +0000 (UTC)
commit d6b4f993206d3d62b788aca69c4e633e9f697ed1
Author: Matthew Barnes <mbarnes redhat com>
Date: Mon Jan 28 15:50:34 2013 -0500
Clean up the mess that is CalObjModType.
Deprecate both CalObjModType and EDataCalObjModType.
Introduce ECalObjModType with equivalent but properly namespaced enum
values, generate a GType for this enum, and swap out CalObjModType for
ECalObjModType throughout the calendar API.
Trying not to break the API here, but this is a freakin mess.
calendar/backends/caldav/e-cal-backend-caldav.c | 42 +++++-----
calendar/backends/file/e-cal-backend-file.c | 80 ++++++++++----------
calendar/backends/http/e-cal-backend-http.c | 4 +-
calendar/libecal/e-cal-client.c | 48 ++++++------
calendar/libecal/e-cal-client.h | 16 ++--
calendar/libecal/e-cal-types.h | 36 +++++++--
calendar/libecal/e-cal-util.c | 14 ++--
calendar/libecal/e-cal-util.h | 12 +---
calendar/libedata-cal/e-cal-backend-sync.c | 8 +-
calendar/libedata-cal/e-cal-backend-sync.h | 8 +-
calendar/libedata-cal/e-cal-backend.c | 4 +-
calendar/libedata-cal/e-cal-backend.h | 8 +-
calendar/libedata-cal/e-data-cal.c | 4 +-
docs/reference/calendar/libecal/libecal-docs.sgml | 1 -
.../calendar/libecal/libecal-sections.txt | 29 ++++----
tests/libecal/client/test-client-bulk-methods.c | 4 +-
tests/libecal/client/test-client-get-view.c | 4 +-
tests/libecal/client/test-client-modify-object.c | 4 +-
tests/libecal/client/test-client-remove-object.c | 4 +-
tests/libecal/client/test-client-revision-view.c | 4 +-
20 files changed, 174 insertions(+), 160 deletions(-)
---
diff --git a/calendar/backends/caldav/e-cal-backend-caldav.c b/calendar/backends/caldav/e-cal-backend-caldav.c
index fadb862..efe2dba 100644
--- a/calendar/backends/caldav/e-cal-backend-caldav.c
+++ b/calendar/backends/caldav/e-cal-backend-caldav.c
@@ -3596,7 +3596,7 @@ static gboolean
remove_instance (ECalBackendCalDAV *cbdav,
icalcomponent *icalcomp,
struct icaltimetype rid,
- CalObjModType mod,
+ ECalObjModType mod,
gboolean also_exdate)
{
icalcomponent *master = icalcomp;
@@ -3811,7 +3811,7 @@ do_create_objects (ECalBackendCalDAV *cbdav,
static void
do_modify_objects (ECalBackendCalDAV *cbdav,
const GSList *calobjs,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GCancellable *cancellable,
@@ -3904,8 +3904,8 @@ do_modify_objects (ECalBackendCalDAV *cbdav,
}
switch (mod) {
- case CALOBJ_MOD_ONLY_THIS:
- case CALOBJ_MOD_THIS:
+ case E_CAL_OBJ_MOD_ONLY_THIS:
+ case E_CAL_OBJ_MOD_THIS:
if (e_cal_component_is_instance (comp)) {
icalcomponent *new_comp = e_cal_component_get_icalcomponent (comp);
@@ -3939,11 +3939,11 @@ do_modify_objects (ECalBackendCalDAV *cbdav,
cache_comp = replace_master (cbdav, cache_comp, icalcomponent_new_clone (e_cal_component_get_icalcomponent (comp)));
}
break;
- case CALOBJ_MOD_ALL:
+ case E_CAL_OBJ_MOD_ALL:
cache_comp = replace_master (cbdav, cache_comp, icalcomponent_new_clone (e_cal_component_get_icalcomponent (comp)));
break;
- case CALOBJ_MOD_THISANDPRIOR:
- case CALOBJ_MOD_THISANDFUTURE:
+ case E_CAL_OBJ_MOD_THIS_AND_PRIOR:
+ case E_CAL_OBJ_MOD_THIS_AND_FUTURE:
break;
}
@@ -3982,7 +3982,7 @@ do_modify_objects (ECalBackendCalDAV *cbdav,
static void
do_remove_objects (ECalBackendCalDAV *cbdav,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GCancellable *cancellable,
@@ -4029,11 +4029,11 @@ do_remove_objects (ECalBackendCalDAV *cbdav,
}
switch (mod) {
- case CALOBJ_MOD_ONLY_THIS:
- case CALOBJ_MOD_THIS:
+ case E_CAL_OBJ_MOD_ONLY_THIS:
+ case E_CAL_OBJ_MOD_THIS:
if (rid && *rid) {
/* remove one instance from the component */
- if (remove_instance (cbdav, cache_comp, icaltime_from_string (rid), mod, mod != CALOBJ_MOD_ONLY_THIS)) {
+ if (remove_instance (cbdav, cache_comp, icaltime_from_string (rid), mod, mod != E_CAL_OBJ_MOD_ONLY_THIS)) {
if (new_components) {
icalcomponent *master = get_master_comp (cbdav, cache_comp);
if (master) {
@@ -4050,11 +4050,11 @@ do_remove_objects (ECalBackendCalDAV *cbdav,
remove_comp_from_cache (cbdav, uid, NULL);
}
break;
- case CALOBJ_MOD_ALL:
+ case E_CAL_OBJ_MOD_ALL:
remove_comp_from_cache (cbdav, uid, NULL);
break;
- case CALOBJ_MOD_THISANDPRIOR:
- case CALOBJ_MOD_THISANDFUTURE:
+ case E_CAL_OBJ_MOD_THIS_AND_PRIOR:
+ case E_CAL_OBJ_MOD_THIS_AND_FUTURE:
break;
}
@@ -4065,7 +4065,7 @@ do_remove_objects (ECalBackendCalDAV *cbdav,
caldav_object.etag = etag;
caldav_object.cdata = NULL;
- if (mod == CALOBJ_MOD_THIS && rid && *rid) {
+ if (mod == E_CAL_OBJ_MOD_THIS && rid && *rid) {
caldav_object.cdata = pack_cobj (cbdav, cache_comp);
caldav_server_put_object (cbdav, &caldav_object, cache_comp, cancellable, perror);
@@ -4077,7 +4077,7 @@ do_remove_objects (ECalBackendCalDAV *cbdav,
etag = NULL;
} else {
/* mark component as out of synch */
- /*if (mod == CALOBJ_MOD_THIS && rid && *rid)
+ /*if (mod == E_CAL_OBJ_MOD_THIS && rid && *rid)
ecalcomp_set_synch_state (cache_comp_master, ECALCOMP_LOCALLY_MODIFIED);
else
ecalcomp_set_synch_state (cache_comp_master, ECALCOMP_LOCALLY_DELETED);*/
@@ -4173,7 +4173,7 @@ process_object (ECalBackendCalDAV *cbdav,
struct icaltimetype now;
gchar *new_obj_str;
gboolean is_declined, is_in_cache;
- CalObjModType mod;
+ ECalObjModType mod;
ECalComponentId *id = e_cal_component_get_id (ecomp);
GError *err = NULL;
@@ -4192,7 +4192,7 @@ process_object (ECalBackendCalDAV *cbdav,
is_in_cache = cache_contains (cbdav, id->uid, NULL) || cache_contains (cbdav, id->uid, id->rid);
new_obj_str = e_cal_component_get_as_string (ecomp);
- mod = e_cal_component_is_instance (ecomp) ? CALOBJ_MOD_THIS : CALOBJ_MOD_ALL;
+ mod = e_cal_component_is_instance (ecomp) ? E_CAL_OBJ_MOD_THIS : E_CAL_OBJ_MOD_ALL;
switch (method) {
case ICAL_METHOD_PUBLISH:
@@ -4257,7 +4257,7 @@ process_object (ECalBackendCalDAV *cbdav,
GSList ids = {0,};
ids.data = id;
- do_remove_objects (cbdav, &ids, CALOBJ_MOD_THIS, &old_components, &new_components, cancellable, &err);
+ do_remove_objects (cbdav, &ids, E_CAL_OBJ_MOD_THIS, &old_components, &new_components, cancellable, &err);
if (!err && old_components && old_components->data) {
if (new_components && new_components->data) {
e_cal_backend_notify_component_modified (backend, old_components->data, new_components->data);
@@ -4408,7 +4408,7 @@ caldav_busy_stub (
EDataCal *cal,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **perror),
@@ -4427,7 +4427,7 @@ caldav_busy_stub (
EDataCal *cal,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **perror),
diff --git a/calendar/backends/http/e-cal-backend-http.c b/calendar/backends/http/e-cal-backend-http.c
index e0b000c..62c4ae3 100644
--- a/calendar/backends/http/e-cal-backend-http.c
+++ b/calendar/backends/http/e-cal-backend-http.c
@@ -1397,7 +1397,7 @@ e_cal_backend_http_modify_objects (ECalBackendSync *backend,
EDataCal *cal,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **perror)
@@ -1411,7 +1411,7 @@ e_cal_backend_http_remove_objects (ECalBackendSync *backend,
EDataCal *cal,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **perror)
diff --git a/calendar/libecal/e-cal-client.c b/calendar/libecal/e-cal-client.c
index 77931dd..3571a5b 100644
--- a/calendar/libecal/e-cal-client.c
+++ b/calendar/libecal/e-cal-client.c
@@ -3881,9 +3881,9 @@ e_cal_client_create_objects_sync (ECalClient *client,
* does not exist on the calendar, an error will be returned.
*
* For recurrent appointments, the @mod argument specifies what to modify,
- * if all instances (CALOBJ_MOD_ALL), a single instance (CALOBJ_MOD_THIS),
- * or a specific set of instances (CALOBJ_MOD_THISNADPRIOR and
- * CALOBJ_MOD_THISANDFUTURE).
+ * if all instances (E_CAL_OBJ_MOD_ALL), a single instance (E_CAL_OBJ_MOD_THIS),
+ * or a specific set of instances (E_CAL_OBJ_MOD_THIS_AND_PRIOR and
+ * E_CAL_OBJ_MOD_THIS_AND_FUTURE).
*
* The call is finished by e_cal_client_modify_object_finish() from
* the @callback.
@@ -3893,7 +3893,7 @@ e_cal_client_create_objects_sync (ECalClient *client,
void
e_cal_client_modify_object (ECalClient *client,
/* const */ icalcomponent *icalcomp,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GAsyncReadyCallback callback,
gpointer user_data)
@@ -3948,9 +3948,9 @@ e_cal_client_modify_object_finish (ECalClient *client,
* does not exist on the calendar, an error will be returned.
*
* For recurrent appointments, the @mod argument specifies what to modify,
- * if all instances (CALOBJ_MOD_ALL), a single instance (CALOBJ_MOD_THIS),
- * or a specific set of instances (CALOBJ_MOD_THISNADPRIOR and
- * CALOBJ_MOD_THISANDFUTURE).
+ * if all instances (E_CAL_OBJ_MOD_ALL), a single instance (E_CAL_OBJ_MOD_THIS),
+ * or a specific set of instances (E_CAL_OBJ_MOD_THISNADPRIOR and
+ * E_CAL_OBJ_MOD_THIS_AND_FUTURE).
*
* Returns: %TRUE if successful, %FALSE otherwise.
*
@@ -3959,7 +3959,7 @@ e_cal_client_modify_object_finish (ECalClient *client,
gboolean
e_cal_client_modify_object_sync (ECalClient *client,
/* const */ icalcomponent *icalcomp,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GError **error)
{
@@ -4000,9 +4000,9 @@ e_cal_client_modify_object_sync (ECalClient *client,
* does not exist on the calendar, an error will be returned.
*
* For recurrent appointments, the @mod argument specifies what to modify,
- * if all instances (CALOBJ_MOD_ALL), a single instance (CALOBJ_MOD_THIS),
- * or a specific set of instances (CALOBJ_MOD_THISNADPRIOR and
- * CALOBJ_MOD_THISANDFUTURE).
+ * if all instances (E_CAL_OBJ_MOD_ALL), a single instance (E_CAL_OBJ_MOD_THIS),
+ * or a specific set of instances (E_CAL_OBJ_MOD_THISNADPRIOR and
+ * E_CAL_OBJ_MOD_THIS_AND_FUTURE).
*
* The call is finished by e_cal_client_modify_objects_finish() from
* the @callback.
@@ -4012,7 +4012,7 @@ e_cal_client_modify_object_sync (ECalClient *client,
void
e_cal_client_modify_objects (ECalClient *client,
/* const */ GSList *comps,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GAsyncReadyCallback callback,
gpointer user_data)
@@ -4069,9 +4069,9 @@ e_cal_client_modify_objects_finish (ECalClient *client,
* does not exist on the calendar, an error will be returned.
*
* For recurrent appointments, the @mod argument specifies what to modify,
- * if all instances (CALOBJ_MOD_ALL), a single instance (CALOBJ_MOD_THIS),
- * or a specific set of instances (CALOBJ_MOD_THISNADPRIOR and
- * CALOBJ_MOD_THISANDFUTURE).
+ * if all instances (E_CAL_OBJ_MOD_ALL), a single instance (E_CAL_OBJ_MOD_THIS),
+ * or a specific set of instances (E_CAL_OBJ_MOD_THISNADPRIOR and
+ * E_CAL_OBJ_MOD_THIS_AND_FUTURE).
*
* Returns: %TRUE if successful, %FALSE otherwise.
*
@@ -4080,7 +4080,7 @@ e_cal_client_modify_objects_finish (ECalClient *client,
gboolean
e_cal_client_modify_objects_sync (ECalClient *client,
/* const */ GSList *comps,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GError **error)
{
@@ -4120,7 +4120,7 @@ e_cal_client_modify_objects_sync (ECalClient *client,
* This function allows the removal of instances of a recurrent
* appointment. By using a combination of the @uid, @rid and @mod
* arguments, you can remove specific instances. If what you want
- * is to remove all instances, use #NULL @rid and CALOBJ_MOD_ALL
+ * is to remove all instances, use #NULL @rid and E_CAL_OBJ_MOD_ALL
* for the @mod.
*
* The call is finished by e_cal_client_remove_object_finish() from
@@ -4132,7 +4132,7 @@ void
e_cal_client_remove_object (ECalClient *client,
const gchar *uid,
const gchar *rid,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GAsyncReadyCallback callback,
gpointer user_data)
@@ -4188,7 +4188,7 @@ e_cal_client_remove_object_finish (ECalClient *client,
* This function allows the removal of instances of a recurrent
* appointment. By using a combination of the @uid, @rid and @mod
* arguments, you can remove specific instances. If what you want
- * is to remove all instances, use #NULL @rid and CALOBJ_MODE_THIS
+ * is to remove all instances, use #NULL @rid and E_CAL_OBJ_MODE_THIS
* for the @mod.
*
* Returns: %TRUE if successful, %FALSE otherwise.
@@ -4199,7 +4199,7 @@ gboolean
e_cal_client_remove_object_sync (ECalClient *client,
const gchar *uid,
const gchar *rid,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GError **error)
{
@@ -4240,7 +4240,7 @@ e_cal_client_remove_object_sync (ECalClient *client,
*
* This function allows the removal of instances of recurrent
* appointments. #ECalComponentId objects can identify specific instances (if rid is not NULL).
- * If what you want is to remove all instances, use a #NULL rid in the #ECalComponentId and CALOBJ_MOD_ALL
+ * If what you want is to remove all instances, use a #NULL rid in the #ECalComponentId and E_CAL_OBJ_MOD_ALL
* for the @mod.
*
* The call is finished by e_cal_client_remove_objects_finish() from
@@ -4251,7 +4251,7 @@ e_cal_client_remove_object_sync (ECalClient *client,
void
e_cal_client_remove_objects (ECalClient *client,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GAsyncReadyCallback callback,
gpointer user_data)
@@ -4301,7 +4301,7 @@ e_cal_client_remove_objects_finish (ECalClient *client,
*
* This function allows the removal of instances of recurrent
* appointments. #ECalComponentId objects can identify specific instances (if rid is not NULL).
- * If what you want is to remove all instances, use a #NULL rid in the #ECalComponentId and CALOBJ_MOD_ALL
+ * If what you want is to remove all instances, use a #NULL rid in the #ECalComponentId and E_CAL_OBJ_MOD_ALL
* for the @mod.
*
* Returns: %TRUE if successful, %FALSE otherwise.
@@ -4311,7 +4311,7 @@ e_cal_client_remove_objects_finish (ECalClient *client,
gboolean
e_cal_client_remove_objects_sync (ECalClient *client,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GError **error)
{
diff --git a/calendar/libecal/e-cal-client.h b/calendar/libecal/e-cal-client.h
index 8383c33..8c02e7f 100644
--- a/calendar/libecal/e-cal-client.h
+++ b/calendar/libecal/e-cal-client.h
@@ -330,7 +330,7 @@ gboolean e_cal_client_create_objects_sync
GError **error);
void e_cal_client_modify_object (ECalClient *client,
icalcomponent *icalcomp,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GAsyncReadyCallback callback,
gpointer user_data);
@@ -340,12 +340,12 @@ gboolean e_cal_client_modify_object_finish
GError **error);
gboolean e_cal_client_modify_object_sync (ECalClient *client,
icalcomponent *icalcomp,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GError **error);
void e_cal_client_modify_objects (ECalClient *client,
GSList *comps,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GAsyncReadyCallback callback,
gpointer user_data);
@@ -356,13 +356,13 @@ gboolean e_cal_client_modify_objects_finish
gboolean e_cal_client_modify_objects_sync
(ECalClient *client,
GSList *comps,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GError **error);
void e_cal_client_remove_object (ECalClient *client,
const gchar *uid,
const gchar *rid,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GAsyncReadyCallback callback,
gpointer user_data);
@@ -373,12 +373,12 @@ gboolean e_cal_client_remove_object_finish
gboolean e_cal_client_remove_object_sync (ECalClient *client,
const gchar *uid,
const gchar *rid,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GError **error);
void e_cal_client_remove_objects (ECalClient *client,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GAsyncReadyCallback callback,
gpointer user_data);
@@ -389,7 +389,7 @@ gboolean e_cal_client_remove_objects_finish
gboolean e_cal_client_remove_objects_sync
(ECalClient *client,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GCancellable *cancellable,
GError **error);
void e_cal_client_receive_objects (ECalClient *client,
diff --git a/calendar/libecal/e-cal-types.h b/calendar/libecal/e-cal-types.h
index 9dd8f75..a51e457 100644
--- a/calendar/libecal/e-cal-types.h
+++ b/calendar/libecal/e-cal-types.h
@@ -45,18 +45,19 @@ typedef enum {
} ECalClientSourceType;
/**
- * EDataCalObjModType:
+ * ECalObjModType:
*
* FIXME Document me!
*
- * Since: 3.6
+ * Since: 3.8
**/
typedef enum {
- This = 1 << 0,
- ThisAndPrior = 1 << 1,
- ThisAndFuture = 1 << 2,
- All = 0x07
-} EDataCalObjModType;
+ E_CAL_OBJ_MOD_THIS = 1 << 0,
+ E_CAL_OBJ_MOD_THIS_AND_PRIOR = 1 << 1,
+ E_CAL_OBJ_MOD_THIS_AND_FUTURE = 1 << 2,
+ E_CAL_OBJ_MOD_ALL = 0x07,
+ E_CAL_OBJ_MOD_ONLY_THIS = 1 << 3
+} ECalObjModType;
/** Everything below this point is deprecated. **/
@@ -124,6 +125,27 @@ typedef enum {
AnyType = 0x07
} EDataCalObjType;
+/**
+ * EDataCalObjModType:
+ *
+ * FIXME Document me!
+ *
+ * Since: 3.6
+ **/
+typedef enum {
+ This = 1 << 0,
+ ThisAndPrior = 1 << 1,
+ ThisAndFuture = 1 << 2,
+ All = 0x07
+} EDataCalObjModType;
+
+typedef ECalObjModType CalObjModType;
+#define CALOBJ_MOD_THIS E_CAL_OBJ_MOD_THIS
+#define CALOBJ_MOD_THISANDPRIOR E_CAL_OBJ_MOD_THIS_AND_PRIOR
+#define CALOBJ_MOD_THISANDFUTURE E_CAL_OBJ_MOD_THIS_AND_FUTURE
+#define CALOBJ_MOD_ALL E_CAL_OBJ_MOD_ALL
+#define CALOBJ_MOD_ONLY_THIS E_CAL_OBJ_MOD_ONLY_THIS
+
#endif /* EDS_DISABLE_DEPRECATED */
G_END_DECLS
diff --git a/calendar/libecal/e-cal-util.c b/calendar/libecal/e-cal-util.c
index 1c431d3..2d02d97 100644
--- a/calendar/libecal/e-cal-util.c
+++ b/calendar/libecal/e-cal-util.c
@@ -1045,16 +1045,16 @@ e_cal_util_construct_instance (icalcomponent *icalcomp,
static inline gboolean
time_matches_rid (struct icaltimetype itt,
struct icaltimetype rid,
- CalObjModType mod)
+ ECalObjModType mod)
{
gint compare;
compare = icaltime_compare (itt, rid);
if (compare == 0)
return TRUE;
- else if (compare < 0 && (mod & CALOBJ_MOD_THISANDPRIOR))
+ else if (compare < 0 && (mod & E_CAL_OBJ_MOD_THIS_AND_PRIOR))
return TRUE;
- else if (compare > 0 && (mod & CALOBJ_MOD_THISANDFUTURE))
+ else if (compare > 0 && (mod & E_CAL_OBJ_MOD_THIS_AND_FUTURE))
return TRUE;
return FALSE;
@@ -1074,7 +1074,7 @@ time_matches_rid (struct icaltimetype itt,
void
e_cal_util_remove_instances (icalcomponent *icalcomp,
struct icaltimetype rid,
- CalObjModType mod)
+ ECalObjModType mod)
{
icalproperty *prop;
struct icaltimetype itt, recur;
@@ -1082,7 +1082,7 @@ e_cal_util_remove_instances (icalcomponent *icalcomp,
icalrecur_iterator *iter;
g_return_if_fail (icalcomp != NULL);
- g_return_if_fail (mod != CALOBJ_MOD_ALL);
+ g_return_if_fail (mod != E_CAL_OBJ_MOD_ALL);
/* First remove RDATEs and EXDATEs in the indicated range. */
for (prop = icalcomponent_get_first_property (icalcomp, ICAL_RDATE_PROPERTY);
@@ -1103,7 +1103,7 @@ e_cal_util_remove_instances (icalcomponent *icalcomp,
}
/* If we're only removing one instance, just add an EXDATE. */
- if (mod == CALOBJ_MOD_THIS) {
+ if (mod == E_CAL_OBJ_MOD_THIS) {
prop = icalproperty_new_exdate (rid);
icalcomponent_add_property (icalcomp, prop);
return;
@@ -1119,7 +1119,7 @@ e_cal_util_remove_instances (icalcomponent *icalcomp,
iter = icalrecur_iterator_new (rule, rid);
recur = icalrecur_iterator_next (iter);
- if (mod & CALOBJ_MOD_THISANDFUTURE) {
+ if (mod & E_CAL_OBJ_MOD_THIS_AND_FUTURE) {
/* If there is a recurrence on or after rid,
* use the UNTIL parameter to truncate the rule
* at rid.
diff --git a/calendar/libecal/e-cal-util.h b/calendar/libecal/e-cal-util.h
index 4067248..2c9a355 100644
--- a/calendar/libecal/e-cal-util.h
+++ b/calendar/libecal/e-cal-util.h
@@ -29,6 +29,7 @@
#include <time.h>
#include <libecal/e-cal-component.h>
#include <libecal/e-cal-recur.h>
+#include <libecal/e-cal-types.h>
G_BEGIN_DECLS
@@ -43,15 +44,6 @@ typedef struct {
void cal_obj_instance_list_free (GList *list);
-/* Used for modifying objects */
-typedef enum {
- CALOBJ_MOD_THIS = 1 << 0,
- CALOBJ_MOD_THISANDPRIOR = 1 << 1,
- CALOBJ_MOD_THISANDFUTURE = 1 << 2,
- CALOBJ_MOD_ONLY_THIS = 1 << 3,
- CALOBJ_MOD_ALL = 0x07
-} CalObjModType;
-
void cal_obj_uid_list_free (GList *list);
icalcomponent * e_cal_util_new_top_level (void);
@@ -183,7 +175,7 @@ icalcomponent * e_cal_util_construct_instance (icalcomponent *icalcomp,
struct icaltimetype rid);
void e_cal_util_remove_instances (icalcomponent *icalcomp,
struct icaltimetype rid,
- CalObjModType mod);
+ ECalObjModType mod);
gchar * e_cal_util_get_system_timezone_location (void);
icaltimezone * e_cal_util_get_system_timezone (void);
diff --git a/calendar/libedata-cal/e-cal-backend-sync.c b/calendar/libedata-cal/e-cal-backend-sync.c
index da3bbd6..7a13327 100644
--- a/calendar/libedata-cal/e-cal-backend-sync.c
+++ b/calendar/libedata-cal/e-cal-backend-sync.c
@@ -316,7 +316,7 @@ e_cal_backend_sync_modify_objects (ECalBackendSync *backend,
EDataCal *cal,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **error)
@@ -350,7 +350,7 @@ e_cal_backend_sync_remove_objects (ECalBackendSync *backend,
EDataCal *cal,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **error)
@@ -703,7 +703,7 @@ cal_backend_modify_objects (ECalBackend *backend,
guint32 opid,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod)
+ ECalObjModType mod)
{
GError *error = NULL;
GSList *old_components = NULL, *new_components = NULL;
@@ -725,7 +725,7 @@ cal_backend_remove_objects (ECalBackend *backend,
guint32 opid,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod)
+ ECalObjModType mod)
{
GError *error = NULL;
GSList *old_components = NULL, *new_components = NULL;
diff --git a/calendar/libedata-cal/e-cal-backend-sync.h b/calendar/libedata-cal/e-cal-backend-sync.h
index e1a153c..3970e32 100644
--- a/calendar/libedata-cal/e-cal-backend-sync.h
+++ b/calendar/libedata-cal/e-cal-backend-sync.h
@@ -103,7 +103,7 @@ struct _ECalBackendSyncClass {
EDataCal *cal,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **error);
@@ -111,7 +111,7 @@ struct _ECalBackendSyncClass {
EDataCal *cal,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **error);
@@ -210,7 +210,7 @@ void e_cal_backend_sync_modify_objects
EDataCal *cal,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **error);
@@ -219,7 +219,7 @@ void e_cal_backend_sync_remove_objects
EDataCal *cal,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **error);
diff --git a/calendar/libedata-cal/e-cal-backend.c b/calendar/libedata-cal/e-cal-backend.c
index c01afaf..1db9e33 100644
--- a/calendar/libedata-cal/e-cal-backend.c
+++ b/calendar/libedata-cal/e-cal-backend.c
@@ -1357,7 +1357,7 @@ e_cal_backend_modify_objects (ECalBackend *backend,
guint32 opid,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod)
+ ECalObjModType mod)
{
g_return_if_fail (backend != NULL);
g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -1392,7 +1392,7 @@ e_cal_backend_remove_objects (ECalBackend *backend,
guint32 opid,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod)
+ ECalObjModType mod)
{
g_return_if_fail (backend != NULL);
g_return_if_fail (E_IS_CAL_BACKEND (backend));
diff --git a/calendar/libedata-cal/e-cal-backend.h b/calendar/libedata-cal/e-cal-backend.h
index 8b5d63b..918b4b9 100644
--- a/calendar/libedata-cal/e-cal-backend.h
+++ b/calendar/libedata-cal/e-cal-backend.h
@@ -194,13 +194,13 @@ struct _ECalBackendClass {
guint32 opid,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod);
+ ECalObjModType mod);
void (*remove_objects) (ECalBackend *backend,
EDataCal *cal,
guint32 opid,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod);
+ ECalObjModType mod);
void (*receive_objects) (ECalBackend *backend,
EDataCal *cal,
guint32 opid,
@@ -321,13 +321,13 @@ void e_cal_backend_modify_objects (ECalBackend *backend,
guint32 opid,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod);
+ ECalObjModType mod);
void e_cal_backend_remove_objects (ECalBackend *backend,
EDataCal *cal,
guint32 opid,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod);
+ ECalObjModType mod);
void e_cal_backend_receive_objects (ECalBackend *backend,
EDataCal *cal,
guint32 opid,
diff --git a/calendar/libedata-cal/e-data-cal.c b/calendar/libedata-cal/e-data-cal.c
index 5a59ce7..df3c2a4 100644
--- a/calendar/libedata-cal/e-data-cal.c
+++ b/calendar/libedata-cal/e-data-cal.c
@@ -133,12 +133,12 @@ typedef struct {
/* OP_MODIFY_OBJECTS */
struct _mo {
GSList *calobjs;
- CalObjModType mod; /* corresponds to EDataCalObjModType */
+ ECalObjModType mod;
} mo;
/* OP_REMOVE_OBJECTS */
struct _ro {
GSList *ids;
- CalObjModType mod; /* corresponds to EDataCalObjModType */
+ ECalObjModType mod;
} ro;
/* OP_GET_TIMEZONE */
gchar *tzid;
diff --git a/docs/reference/calendar/libecal/libecal-docs.sgml b/docs/reference/calendar/libecal/libecal-docs.sgml
index cc84b66..22f615b 100644
--- a/docs/reference/calendar/libecal/libecal-docs.sgml
+++ b/docs/reference/calendar/libecal/libecal-docs.sgml
@@ -15,7 +15,6 @@
<xi:include href="xml/e-cal-component.xml"/>
<xi:include href="xml/e-cal-recur.xml"/>
<xi:include href="xml/e-cal-time-util.xml"/>
- <xi:include href="xml/e-cal-types.xml"/>
<xi:include href="xml/e-cal-util.xml"/>
<xi:include href="xml/e-cal-system-timezone.xml"/>
<xi:include href="xml/e-cal-check-timezones.xml"/>
diff --git a/docs/reference/calendar/libecal/libecal-sections.txt b/docs/reference/calendar/libecal/libecal-sections.txt
index b59f407..ba1f1d1 100644
--- a/docs/reference/calendar/libecal/libecal-sections.txt
+++ b/docs/reference/calendar/libecal/libecal-sections.txt
@@ -141,6 +141,7 @@ e_cal_client_create_object_sync
e_cal_client_create_objects
e_cal_client_create_objects_finish
e_cal_client_create_objects_sync
+ECalObjModType
e_cal_client_modify_object
e_cal_client_modify_object_finish
e_cal_client_modify_object_sync
@@ -430,23 +431,9 @@ tm_to_icaltimetype
</SECTION>
<SECTION>
-<FILE>e-cal-types</FILE>
-EDataCalObjModType
-<SUBSECTION Deprecated>
-E_CALENDAR_ERROR
-e_calendar_error_quark
-ECalChangeType
-ECalChange
-ECalendarStatus
-E_CALENDAR_STATUS_CORBA_EXCEPTION
-EDataCalObjType
-</SECTION>
-
-<SECTION>
<FILE>e-cal-util</FILE>
CalObjInstance
cal_obj_instance_list_free
-CalObjModType
cal_obj_uid_list_free
e_cal_util_new_top_level
e_cal_util_new_component
@@ -503,6 +490,20 @@ e_cal_util_get_component_occur_times
<SUBSECTION Deprecated>
CalMode
cal_mode_to_corba
+E_CALENDAR_ERROR
+e_calendar_error_quark
+ECalChangeType
+ECalChange
+ECalendarStatus
+E_CALENDAR_STATUS_CORBA_EXCEPTION
+EDataCalObjType
+EDataCalObjModType
+CalObjModType
+CALOBJ_MOD_THIS
+CALOBJ_MOD_THISANDPRIOR
+CALOBJ_MOD_THISANDFUTURE
+CALOBJ_MOD_ALL
+CALOBJ_MOD_ONLY_THIS
</SECTION>
<SECTION>
diff --git a/tests/libecal/client/test-client-bulk-methods.c b/tests/libecal/client/test-client-bulk-methods.c
index 69ccf26..32a369b 100644
--- a/tests/libecal/client/test-client-bulk-methods.c
+++ b/tests/libecal/client/test-client-bulk-methods.c
@@ -141,7 +141,7 @@ test_bulk_methods (ECalClient *cal_client,
}
/* Save the modified objects in bulk */
- if (!e_cal_client_modify_objects_sync (cal_client, icalcomps, CALOBJ_MOD_ALL, NULL, &error))
+ if (!e_cal_client_modify_objects_sync (cal_client, icalcomps, E_CAL_OBJ_MOD_ALL, NULL, &error))
g_error ("modify objects sync: %s", error->message);
/* Retrieve all the objects and check that they have been modified */
@@ -150,7 +150,7 @@ test_bulk_methods (ECalClient *cal_client,
/* Remove all the objects in bulk */
ids = uid_slist_to_ecalcomponentid_slist (uids);
- if (!e_cal_client_remove_objects_sync (cal_client, ids, CALOBJ_MOD_ALL, NULL, &error))
+ if (!e_cal_client_remove_objects_sync (cal_client, ids, E_CAL_OBJ_MOD_ALL, NULL, &error))
g_error ("remove objects sync: %s", error->message);
g_slist_free_full (ids, (GDestroyNotify) e_cal_component_free_id);
diff --git a/tests/libecal/client/test-client-get-view.c b/tests/libecal/client/test-client-get-view.c
index 29c18b1..d2790e7 100644
--- a/tests/libecal/client/test-client-get-view.c
+++ b/tests/libecal/client/test-client-get-view.c
@@ -115,10 +115,10 @@ alter_cal_client (gpointer user_data)
icalcomponent_set_uid (icalcomp, uid);
icalcomponent_set_summary (icalcomp, "Modified event summary");
- if (!e_cal_client_modify_object_sync (cal_client, icalcomp, CALOBJ_MOD_ALL, NULL, &error))
+ if (!e_cal_client_modify_object_sync (cal_client, icalcomp, E_CAL_OBJ_MOD_ALL, NULL, &error))
g_error ("modify object sync: %s", error->message);
- if (!e_cal_client_remove_object_sync (cal_client, uid, NULL, CALOBJ_MOD_ALL, NULL, &error))
+ if (!e_cal_client_remove_object_sync (cal_client, uid, NULL, E_CAL_OBJ_MOD_ALL, NULL, &error))
g_error ("remove object sync: %s", error->message);
g_free (uid);
diff --git a/tests/libecal/client/test-client-modify-object.c b/tests/libecal/client/test-client-modify-object.c
index 05b595c..97f774e 100644
--- a/tests/libecal/client/test-client-modify-object.c
+++ b/tests/libecal/client/test-client-modify-object.c
@@ -59,7 +59,7 @@ test_modify_object_sync (ETestServerFixture *fixture,
icalcomponent_set_summary (icalcomp, EVENT_SUMMARY);
- if (!e_cal_client_modify_object_sync (cal_client, icalcomp, CALOBJ_MOD_ALL, NULL, &error))
+ if (!e_cal_client_modify_object_sync (cal_client, icalcomp, E_CAL_OBJ_MOD_ALL, NULL, &error))
g_error ("modify object sync: %s", error->message);
icalcomponent_free (icalcomp);
@@ -117,7 +117,7 @@ test_modify_object_async (ETestServerFixture *fixture,
icalcomponent_set_summary (icalcomp, EVENT_SUMMARY);
- e_cal_client_modify_object (cal_client, icalcomp, CALOBJ_MOD_ALL, NULL, async_modify_result_ready, fixture->loop);
+ e_cal_client_modify_object (cal_client, icalcomp, E_CAL_OBJ_MOD_ALL, NULL, async_modify_result_ready, fixture->loop);
icalcomponent_free (icalcomp);
g_main_loop_run (fixture->loop);
diff --git a/tests/libecal/client/test-client-remove-object.c b/tests/libecal/client/test-client-remove-object.c
index 84b0475..2ae31bd 100644
--- a/tests/libecal/client/test-client-remove-object.c
+++ b/tests/libecal/client/test-client-remove-object.c
@@ -46,7 +46,7 @@ test_remove_object_sync (ETestServerFixture *fixture,
uid = create_object (cal_client);
g_assert (uid != NULL);
- if (!e_cal_client_remove_object_sync (cal_client, uid, NULL, CALOBJ_MOD_ALL, NULL, &error))
+ if (!e_cal_client_remove_object_sync (cal_client, uid, NULL, E_CAL_OBJ_MOD_ALL, NULL, &error))
g_error ("remove object sync: %s", error->message);
g_free (uid);
@@ -81,7 +81,7 @@ test_remove_object_async (ETestServerFixture *fixture,
uid = create_object (cal_client);
g_assert (uid != NULL);
- e_cal_client_remove_object (cal_client, uid, NULL, CALOBJ_MOD_ALL, NULL, async_remove_result_ready, fixture->loop);
+ e_cal_client_remove_object (cal_client, uid, NULL, E_CAL_OBJ_MOD_ALL, NULL, async_remove_result_ready, fixture->loop);
g_free (uid);
g_main_loop_run (fixture->loop);
}
diff --git a/tests/libecal/client/test-client-revision-view.c b/tests/libecal/client/test-client-revision-view.c
index c589b39..6ebe717 100644
--- a/tests/libecal/client/test-client-revision-view.c
+++ b/tests/libecal/client/test-client-revision-view.c
@@ -152,10 +152,10 @@ alter_cal_client (gpointer user_data)
icalcomponent_set_uid (icalcomp, uid);
icalcomponent_set_summary (icalcomp, "Modified event summary");
- if (!e_cal_client_modify_object_sync (cal_client, icalcomp, CALOBJ_MOD_ALL, NULL, &error))
+ if (!e_cal_client_modify_object_sync (cal_client, icalcomp, E_CAL_OBJ_MOD_ALL, NULL, &error))
g_error ("modify object sync: %s", error->message);
- if (!e_cal_client_remove_object_sync (cal_client, uid, NULL, CALOBJ_MOD_ALL, NULL, &error))
+ if (!e_cal_client_remove_object_sync (cal_client, uid, NULL, E_CAL_OBJ_MOD_ALL, NULL, &error))
g_error ("remove object sync: %s", error->message);
g_free (uid);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/calendar/backends/file/e-cal-backend-file.c b/calendar/backends/file/e-cal-backend-file.c
index 94b4df6..1fdf89c 100644
--- a/calendar/backends/file/e-cal-backend-file.c
+++ b/calendar/backends/file/e-cal-backend-file.c
@@ -2253,7 +2253,7 @@ typedef struct {
ECalBackendFile *cbfile;
ECalBackendFileObject *obj_data;
const gchar *rid;
- CalObjModType mod;
+ ECalObjModType mod;
} RemoveRecurrenceData;
static gboolean
@@ -2269,8 +2269,8 @@ remove_object_instance_cb (gpointer key,
instancett = icaltime_as_timet (get_rid_icaltime (instance));
if (fromtt > 0 && instancett > 0) {
- if ((rrdata->mod == CALOBJ_MOD_THISANDPRIOR && instancett <= fromtt) ||
- (rrdata->mod == CALOBJ_MOD_THISANDFUTURE && instancett >= fromtt)) {
+ if ((rrdata->mod == E_CAL_OBJ_MOD_THIS_AND_PRIOR && instancett <= fromtt) ||
+ (rrdata->mod == E_CAL_OBJ_MOD_THIS_AND_FUTURE && instancett >= fromtt)) {
/* remove the component from our data */
icalcomponent_remove_component (
rrdata->cbfile->priv->icalcomp,
@@ -2291,7 +2291,7 @@ e_cal_backend_file_modify_objects (ECalBackendSync *backend,
EDataCal *cal,
GCancellable *cancellable,
const GSList *calobjs,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **error)
@@ -2307,10 +2307,10 @@ e_cal_backend_file_modify_objects (ECalBackendSync *backend,
e_return_data_cal_error_if_fail (priv->icalcomp != NULL, NoSuchCal);
e_return_data_cal_error_if_fail (calobjs != NULL, ObjectNotFound);
switch (mod) {
- case CALOBJ_MOD_THIS:
- case CALOBJ_MOD_THISANDPRIOR:
- case CALOBJ_MOD_THISANDFUTURE:
- case CALOBJ_MOD_ALL:
+ case E_CAL_OBJ_MOD_THIS:
+ case E_CAL_OBJ_MOD_THIS_AND_PRIOR:
+ case E_CAL_OBJ_MOD_THIS_AND_FUTURE:
+ case E_CAL_OBJ_MOD_ALL:
break;
default:
g_propagate_error (error, EDC_ERROR (NotSupported));
@@ -2391,7 +2391,7 @@ e_cal_backend_file_modify_objects (ECalBackendSync *backend,
/* handle mod_type */
switch (mod) {
- case CALOBJ_MOD_THIS :
+ case E_CAL_OBJ_MOD_THIS:
if (!rid || !*rid) {
if (old_components)
*old_components = g_slist_prepend (*old_components, obj_data->full_object ? e_cal_component_clone (obj_data->full_object) : NULL);
@@ -2443,8 +2443,8 @@ e_cal_backend_file_modify_objects (ECalBackendSync *backend,
priv->comp = g_list_append (priv->comp, comp);
obj_data->recurrences_list = g_list_append (obj_data->recurrences_list, comp);
break;
- case CALOBJ_MOD_THISANDPRIOR :
- case CALOBJ_MOD_THISANDFUTURE :
+ case E_CAL_OBJ_MOD_THIS_AND_PRIOR:
+ case E_CAL_OBJ_MOD_THIS_AND_FUTURE:
if (!rid || !*rid) {
if (old_components)
*old_components = g_slist_prepend (*old_components, obj_data->full_object ? e_cal_component_clone (obj_data->full_object) : NULL);
@@ -2509,7 +2509,7 @@ e_cal_backend_file_modify_objects (ECalBackendSync *backend,
priv->comp = g_list_append (priv->comp, comp);
obj_data->recurrences_list = g_list_append (obj_data->recurrences_list, comp);
break;
- case CALOBJ_MOD_ALL :
+ case E_CAL_OBJ_MOD_ALL :
/* Remove the old version */
if (old_components)
*old_components = g_slist_prepend (*old_components, obj_data->full_object ? e_cal_component_clone (obj_data->full_object) : NULL);
@@ -2548,7 +2548,7 @@ e_cal_backend_file_modify_objects (ECalBackendSync *backend,
g_list_free (detached);
}
break;
- case CALOBJ_MOD_ONLY_THIS:
+ case E_CAL_OBJ_MOD_ONLY_THIS:
/* not reached, keep compiler happy */
break;
}
@@ -2578,9 +2578,9 @@ e_cal_backend_file_modify_objects (ECalBackendSync *backend,
* Remove one and only one instance. The object may be empty
* afterwards, in which case it will be removed completely.
*
* @mod CALOBJ_MOD_THIS or CAL_OBJ_MOD_ONLY_THIS: the later only removes
* the instance, the former also adds an EXDATE if rid is set
* TODO: CAL_OBJ_MOD_ONLY_THIS
* @uid pointer to UID which must remain valid even if the object gets
* removed
* @rid NULL, "", or non-empty string when manipulating a specific recurrence;
@@ -2593,7 +2593,7 @@ remove_instance (ECalBackendFile *cbfile,
ECalBackendFileObject *obj_data,
const gchar *uid,
const gchar *rid,
- CalObjModType mod,
+ ECalObjModType mod,
ECalComponent **old_comp,
ECalComponent **new_comp,
GError **error)
@@ -2613,14 +2613,14 @@ remove_instance (ECalBackendFile *cbfile,
/* Removing without parent or not modifying parent?
* Report removal to caller. */
if (old_comp &&
- (!obj_data->full_object || mod == CALOBJ_MOD_ONLY_THIS)) {
+ (!obj_data->full_object || mod == E_CAL_OBJ_MOD_ONLY_THIS)) {
*old_comp = e_cal_component_clone (comp);
}
/* Reporting parent modification to caller?
* Report directly instead of going via caller. */
if (obj_data->full_object &&
- mod != CALOBJ_MOD_ONLY_THIS) {
+ mod != E_CAL_OBJ_MOD_ONLY_THIS) {
/* old object string not provided,
* instead rely on the view detecting
* whether it contains the id */
@@ -2637,7 +2637,7 @@ remove_instance (ECalBackendFile *cbfile,
cbfile->priv->comp = g_list_remove (cbfile->priv->comp, comp);
obj_data->recurrences_list = g_list_remove (obj_data->recurrences_list, comp);
g_hash_table_remove (obj_data->recurrences, rid);
- } else if (mod == CALOBJ_MOD_ONLY_THIS) {
+ } else if (mod == E_CAL_OBJ_MOD_ONLY_THIS) {
if (error)
g_propagate_error (error, EDC_ERROR (ObjectNotFound));
return obj_data;
@@ -2656,7 +2656,7 @@ remove_instance (ECalBackendFile *cbfile,
}
/* avoid modifying parent? */
- if (mod == CALOBJ_MOD_ONLY_THIS)
+ if (mod == E_CAL_OBJ_MOD_ONLY_THIS)
return obj_data;
/* remove the main component from our data before modifying it */
@@ -2672,7 +2672,7 @@ remove_instance (ECalBackendFile *cbfile,
e_cal_util_remove_instances (
e_cal_component_get_icalcomponent (obj_data->full_object),
- icaltime_from_string (rid), CALOBJ_MOD_THIS);
+ icaltime_from_string (rid), E_CAL_OBJ_MOD_THIS);
/* Since we are only removing one instance of recurrence
* event, update the last modified time on the component */
@@ -2695,8 +2695,8 @@ remove_instance (ECalBackendFile *cbfile,
if (!obj_data->full_object) {
/* Nothing to do, parent doesn't exist. Tell
* caller about this? Not an error with
- * CALOBJ_MOD_THIS. */
- if (mod == CALOBJ_MOD_ONLY_THIS && error)
+ * E_CAL_OBJ_MOD_THIS. */
+ if (mod == E_CAL_OBJ_MOD_ONLY_THIS && error)
g_propagate_error (error, EDC_ERROR (ObjectNotFound));
return obj_data;
}
@@ -2777,7 +2777,7 @@ e_cal_backend_file_remove_objects (ECalBackendSync *backend,
EDataCal *cal,
GCancellable *cancellable,
const GSList *ids,
- CalObjModType mod,
+ ECalObjModType mod,
GSList **old_components,
GSList **new_components,
GError **error)
@@ -2795,11 +2795,11 @@ e_cal_backend_file_remove_objects (ECalBackendSync *backend,
e_return_data_cal_error_if_fail (new_components != NULL, ObjectNotFound);
switch (mod) {
- case CALOBJ_MOD_THIS:
- case CALOBJ_MOD_THISANDPRIOR:
- case CALOBJ_MOD_THISANDFUTURE:
- case CALOBJ_MOD_ONLY_THIS:
- case CALOBJ_MOD_ALL:
+ case E_CAL_OBJ_MOD_THIS:
+ case E_CAL_OBJ_MOD_THIS_AND_PRIOR:
+ case E_CAL_OBJ_MOD_THIS_AND_FUTURE:
+ case E_CAL_OBJ_MOD_ONLY_THIS:
+ case E_CAL_OBJ_MOD_ALL:
break;
default:
g_propagate_error (error, EDC_ERROR (NotSupported));
@@ -2819,9 +2819,9 @@ e_cal_backend_file_remove_objects (ECalBackendSync *backend,
g_propagate_error (error, EDC_ERROR (ObjectNotFound));
return;
}
- /* Check that it has a recurrence id if mod is CALOBJ_MOD_THISANDPRIOR
- or CALOBJ_MOD_THISANDFUTURE */
- if ((mod == CALOBJ_MOD_THISANDPRIOR || mod == CALOBJ_MOD_THISANDFUTURE) &&
+ /* Check that it has a recurrence id if mod is E_CAL_OBJ_MOD_THIS_AND_PRIOR
+ or E_CAL_OBJ_MOD_THIS_AND_FUTURE */
+ if ((mod == E_CAL_OBJ_MOD_THIS_AND_PRIOR || mod == E_CAL_OBJ_MOD_THIS_AND_FUTURE) &&
(!id->rid || !*(id->rid))) {
g_rec_mutex_unlock (&priv->idle_save_rmutex);
g_propagate_error (error, EDC_ERROR (ObjectNotFound));
@@ -2849,7 +2849,7 @@ e_cal_backend_file_remove_objects (ECalBackendSync *backend,
recur_id = id->rid;
switch (mod) {
- case CALOBJ_MOD_ALL :
+ case E_CAL_OBJ_MOD_ALL :
*old_components = g_slist_prepend (*old_components, clone_ecalcomp_from_fileobject (obj_data, recur_id));
*new_components = g_slist_prepend (*new_components, NULL);
@@ -2857,8 +2857,8 @@ e_cal_backend_file_remove_objects (ECalBackendSync *backend,
g_list_foreach (obj_data->recurrences_list, notify_comp_removed_cb, cbfile);
remove_component (cbfile, id->uid, obj_data);
break;
- case CALOBJ_MOD_ONLY_THIS:
- case CALOBJ_MOD_THIS: {
+ case E_CAL_OBJ_MOD_ONLY_THIS:
+ case E_CAL_OBJ_MOD_THIS: {
ECalComponent *old_component = NULL;
ECalComponent *new_component = NULL;
@@ -2870,8 +2870,8 @@ e_cal_backend_file_remove_objects (ECalBackendSync *backend,
*new_components = g_slist_prepend (*new_components, new_component);
break;
}
- case CALOBJ_MOD_THISANDPRIOR :
- case CALOBJ_MOD_THISANDFUTURE :
+ case E_CAL_OBJ_MOD_THIS_AND_PRIOR:
+ case E_CAL_OBJ_MOD_THIS_AND_FUTURE:
comp = obj_data->full_object;
if (comp) {
@@ -2947,7 +2947,7 @@ cancel_received_object (ECalBackendFile *cbfile,
rid = e_cal_component_get_recurid_as_string (comp);
if (rid && *rid) {
obj_data = remove_instance (
- cbfile, obj_data, uid, rid, CALOBJ_MOD_THIS,
+ cbfile, obj_data, uid, rid, E_CAL_OBJ_MOD_THIS,
old_comp, new_comp, NULL);
if (obj_data && obj_data->full_object && !*new_comp) {
*new_comp = e_cal_component_clone (obj_data->full_object);
@@ -3202,7 +3202,7 @@ e_cal_backend_file_receive_objects (ECalBackendSync *backend,
ECalComponent *ignore_comp = NULL;
remove_instance (
- cbfile, obj_data, uid, rid, CALOBJ_MOD_THIS,
+ cbfile, obj_data, uid, rid, E_CAL_OBJ_MOD_THIS,
&old_component, &ignore_comp, NULL);
if (ignore_comp)
@@ -2578,9 +2578,9 @@ e_cal_backend_file_modify_objects (ECalBackendSync *backend,
* afterwards, in which case it will be removed completely.
*
- * @mod CALOBJ_MOD_THIS or CAL_OBJ_MOD_ONLY_THIS: the later only removes
- * the instance, the former also adds an EXDATE if rid is set
- * TODO: CAL_OBJ_MOD_ONLY_THIS
+ * @mod E_CAL_OBJ_MOD_THIS or E_CAL_OBJ_MOD_ONLY_THIS: the later only
+ * removes the instance, the former also adds an EXDATE if rid is set
+ * TODO: E_CAL_OBJ_MOD_ONLY_THIS
* @uid pointer to UID which must remain valid even if the object gets
* removed